[rhythmbox/gobject-introspection: 204/205] fix a bunch of annotations



commit 3db2295f212afeddf570da9444f80abdbcc8734f
Author: Jonathan Matthew <jonathan d14n org>
Date:   Tue Oct 26 20:18:02 2010 +1000

    fix a bunch of annotations

 backends/rb-encoder.c                |    4 ++--
 backends/rb-player.c                 |    2 +-
 bindings/gi/Makefile.am              |    3 +++
 lib/rb-builder-helpers.c             |    2 +-
 lib/rb-debug.c                       |   10 +++++-----
 lib/rb-file-helpers.c                |    4 ++--
 lib/rb-util.c                        |    4 ++--
 metadata/rb-metadata-dbus-client.c   |    4 ++--
 rhythmdb/rhythmdb-query.c            |    8 +++++---
 rhythmdb/rhythmdb-song-entry-types.c |    2 +-
 rhythmdb/rhythmdb.c                  |   20 ++++++++++----------
 shell/rb-history.c                   |    4 ++--
 shell/rb-playlist-manager.c          |   26 +++++++++++++-------------
 shell/rb-plugin.c                    |    2 +-
 shell/rb-shell-preferences.c         |    4 ++--
 shell/rb-shell.c                     |    2 +-
 sources/rb-media-player-source.c     |   12 ++++++------
 sources/rb-source.c                  |    6 +++---
 sources/rb-sourcelist-model.c        |    2 +-
 widgets/rb-dialog.c                  |    2 +-
 widgets/rb-segmented-bar.c           |    8 ++++++++
 21 files changed, 72 insertions(+), 59 deletions(-)
---
diff --git a/backends/rb-encoder.c b/backends/rb-encoder.c
index 87bfe32..6c6d327 100644
--- a/backends/rb-encoder.c
+++ b/backends/rb-encoder.c
@@ -208,7 +208,7 @@ rb_encoder_get_type (void)
  *
  * Returns the #RBEncoderFactory instance.
  *
- * Return value: the #RBEncoderFactory
+ * Return value: (transfer none): the #RBEncoderFactory
  */
 RBEncoderFactory *
 rb_encoder_factory_get ()
@@ -313,7 +313,7 @@ rb_encoder_get_missing_plugins (RBEncoder *encoder,
  *
  * Creates a new #RBEncoder instance.
  *
- * Return value: the new #RBEncoder
+ * Return value: (transfer full): the new #RBEncoder
  */
 RBEncoder*
 rb_encoder_new (void)
diff --git a/backends/rb-player.c b/backends/rb-player.c
index fc10c4f..c8de8fc 100644
--- a/backends/rb-player.c
+++ b/backends/rb-player.c
@@ -576,7 +576,7 @@ rb_player_multiple_open (RBPlayer *player)
  *
  * Creates a new player object.
  *
- * Return value: new player object.
+ * Return value: (transfer full): new player object.
  */
 RBPlayer*
 rb_player_new (gboolean want_crossfade, GError **error)
diff --git a/bindings/gi/Makefile.am b/bindings/gi/Makefile.am
index a5dc969..ee2c931 100644
--- a/bindings/gi/Makefile.am
+++ b/bindings/gi/Makefile.am
@@ -119,6 +119,7 @@ rhythmdb_introspection_sources = \
 		rhythmdb/rhythmdb-query-results.c \
 		rhythmdb/rhythmdb-import-job.h \
 		rhythmdb/rhythmdb-import-job.c \
+		rhythmdb/rhythmdb-song-entry-types.c \
 		rhythmdb/rb-refstring.h \
 		rhythmdb/rb-refstring.c
 
@@ -136,6 +137,7 @@ RhythmDB_0_13_gir_CFLAGS = $(RHYTHMBOX_CFLAGS_NOWARN) $(TOTEM_PLPARSER_CFLAGS) $
 RhythmDB_0_13_gir_LIBS = $(top_builddir)/shell/librhythmbox-core.la
 RhythmDB_0_13_gir_FILES = $(addprefix $(top_srcdir)/,$(rhythmdb_introspection_sources))
 RhythmDB_0_13_gir_PACKAGES = rhythmbox
+RhythmDB_0_13_gir_SCANNERFLAGS = --symbol-prefix rhythmdb_
 
 RB-0.13.gir: $(top_builddir)/shell/librhythmbox-core.la RhythmDB-0.13.gir
 RB_0_13_gir_INCLUDES = GObject-2.0 Gio-2.0 Gtk-$(GTK_MAJ_VER) Gst-0.10 libxml2-2.0 RhythmDB-0.13
@@ -143,6 +145,7 @@ RB_0_13_gir_CFLAGS = $(RHYTHMBOX_CFLAGS_NOWARN) $(TOTEM_PLPARSER_CFLAGS) $(DBUS_
 RB_0_13_gir_LIBS = $(top_builddir)/shell/librhythmbox-core.la
 RB_0_13_gir_FILES = $(addprefix $(top_srcdir)/,$(rb_introspection_sources))
 RB_0_13_gir_PACKAGES = rhythmbox
+RB_0_13_gir_SCANNERFLAGS = --symbol-prefix rb_
 
 INTROSPECTION_GIRS += MPID-0.13.gir RhythmDB-0.13.gir RB-0.13.gir
 
diff --git a/lib/rb-builder-helpers.c b/lib/rb-builder-helpers.c
index 10cf3cd..bc8ed33 100644
--- a/lib/rb-builder-helpers.c
+++ b/lib/rb-builder-helpers.c
@@ -51,7 +51,7 @@
  * relative to the shared data directory, or its 'ui' or 'art'
  * subdirectories.
  *
- * Return value: #GtkBuilder object built from the file
+ * Return value: (transfer full): #GtkBuilder object built from the file
  */
 GtkBuilder *
 rb_builder_load (const char *file, gpointer user_data)
diff --git a/lib/rb-debug.c b/lib/rb-debug.c
index 62454fb..80360e3 100644
--- a/lib/rb-debug.c
+++ b/lib/rb-debug.c
@@ -248,7 +248,7 @@ rb_debug_init_match (const char *match)
  * this debug output code that will produce the same debug output
  * settings.
  *
- * Return value: debug output arguments, must be freed with #g_strfreev()
+ * Return value: (transfer full): debug output arguments, must be freed with #g_strfreev()
  */
 char **
 rb_debug_get_args (void)
@@ -308,7 +308,7 @@ struct RBProfiler
 };
 
 /**
- * rb_profiler_new:
+ * rb_profiler_new: (skip):
  * @name: profiler name
  *
  * Creates a new profiler instance.  This can be used to
@@ -334,7 +334,7 @@ rb_profiler_new (const char *name)
 }
 
 /**
- * rb_profiler_dump:
+ * rb_profiler_dump: (skip):
  * @profiler: profiler instance
  *
  * Produces debug output for the profiler instance,
@@ -358,7 +358,7 @@ rb_profiler_dump (RBProfiler *profiler)
 }
 
 /**
- * rb_profiler_reset:
+ * rb_profiler_reset: (skip):
  * @profiler: profiler instance
  *
  * Resets the elapsed time for the profiler
@@ -375,7 +375,7 @@ rb_profiler_reset (RBProfiler *profiler)
 }
 
 /**
- * rb_profiler_free:
+ * rb_profiler_free: (skip):
  * @profiler: profiler instance to destroy
  *
  * Frees the memory associated with a profiler instance.
diff --git a/lib/rb-file-helpers.c b/lib/rb-file-helpers.c
index 1b121af..6b61e30 100644
--- a/lib/rb-file-helpers.c
+++ b/lib/rb-file-helpers.c
@@ -838,7 +838,7 @@ _uri_handle_recurse (GFile *dir,
  * rb_uri_handle_recursively:
  * @uri: URI to visit
  * @cancel: an optional #GCancellable to allow cancellation
- * @func: Callback function
+ * @func: (scope call): Callback function
  * @user_data: Data for callback function
  *
  * Calls @func for each file found under the directory identified by @uri.
@@ -1384,7 +1384,7 @@ rb_uri_create_parent_dirs (const char *uri, GError **error)
  * the nearest extant ancestor of the specified file, which may be
  * the file itself if it exists.
  * 
- * Return value: #GFile for the nearest extant ancestor
+ * Return value: (transfer full): #GFile for the nearest extant ancestor
  */
 GFile *
 rb_file_find_extant_parent (GFile *file)
diff --git a/lib/rb-util.c b/lib/rb-util.c
index 507fd5c..ebf486a 100644
--- a/lib/rb-util.c
+++ b/lib/rb-util.c
@@ -337,7 +337,7 @@ totem_pixbuf_mirror (GdkPixbuf *pixbuf)
  * Same as @gtk_image_new_from_stock except that it mirrors the icons for RTL
  * languages.
  *
- * Return value: a #GtkImage of the requested stock item
+ * Return value: (transfer full): a #GtkImage of the requested stock item
  */
 GtkWidget *
 rb_image_new_from_stock (const gchar *stock_id, GtkIconSize size)
@@ -1223,7 +1223,7 @@ rb_set_tree_view_column_fixed_width (GtkWidget  *treeview,
  * Creates a new #GdkPixbuf from the original one, for a target of
  * size, respecting the aspect ratio of the image.
  *
- * Return value: scaled #GdkPixbuf
+ * Return value: (transfer full): scaled #GdkPixbuf
  */
 GdkPixbuf *
 rb_scale_pixbuf_to_size (GdkPixbuf *pixbuf, GtkIconSize size)
diff --git a/metadata/rb-metadata-dbus-client.c b/metadata/rb-metadata-dbus-client.c
index 4b0242b..56e83bb 100644
--- a/metadata/rb-metadata-dbus-client.c
+++ b/metadata/rb-metadata-dbus-client.c
@@ -744,8 +744,8 @@ rb_metadata_can_save (RBMetaData *md, const char *mimetype)
  * Constructs a list of the media types for which the metadata backend
  * implements tag saving.
  *
- * Return value: (array zero-terminated=1):  a NULL-terminated array of
- * media type strings.  Use g_strfreev to free it.
+ * Return value: (transfer full) (array zero-terminated=1): a NULL-terminated
+ * array of media type strings.  Use g_strfreev to free it.
  */
 char **
 rb_metadata_get_saveable_types (RBMetaData *md)
diff --git a/rhythmdb/rhythmdb-query.c b/rhythmdb/rhythmdb-query.c
index 6f8bcea..294bd41 100644
--- a/rhythmdb/rhythmdb-query.c
+++ b/rhythmdb/rhythmdb-query.c
@@ -63,7 +63,8 @@
  *
  * Creates a copy of a query.
  *
- * Return value: a copy of the passed query. It must be freed with rhythmdb_query_free()
+ * Return value: (transfer full): a copy of the passed query.
+ * It must be freed with rhythmdb_query_free()
  **/
 GPtrArray *
 rhythmdb_query_copy (GPtrArray *array)
@@ -205,7 +206,8 @@ rhythmdb_query_parse_valist (RhythmDB *db, va_list args)
  * 	b) that have "cat" in their title, or
  * 	c) have a rating of at least 2.5, and a play count of at most 10
  *
- * Returns: a the newly created query. It must be freed with rhythmdb_query_free()
+ * Returns: (transfer full): a the newly created query.
+ * It must be freed with rhythmdb_query_free()
  **/
 GPtrArray *
 rhythmdb_query_parse (RhythmDB *db, ...)
@@ -593,7 +595,7 @@ rhythmdb_query_serialize (RhythmDB *db, GPtrArray *query,
  *
  * Converts a serialized query back into a @GPtrArray query.
  *
- * Return value: deserialized query.
+ * Return value: (transfer full): deserialized query.
  */
 GPtrArray *
 rhythmdb_query_deserialize (RhythmDB *db, xmlNodePtr parent)
diff --git a/rhythmdb/rhythmdb-song-entry-types.c b/rhythmdb/rhythmdb-song-entry-types.c
index 1ed629b..9e83e07 100644
--- a/rhythmdb/rhythmdb-song-entry-types.c
+++ b/rhythmdb/rhythmdb-song-entry-types.c
@@ -194,7 +194,7 @@ import_error_update_availability (RhythmDBEntryType *entry_type,
  *
  * Returns the #RhythmDBEntryType for normal songs.
  *
- * Return value: (transfer none): the entry type for normal songs
+ * Returns: (transfer none): the entry type for normal songs
  */
 RhythmDBEntryType *
 rhythmdb_get_song_entry_type (void)
diff --git a/rhythmdb/rhythmdb.c b/rhythmdb/rhythmdb.c
index ebd0b11..be9b462 100644
--- a/rhythmdb/rhythmdb.c
+++ b/rhythmdb/rhythmdb.c
@@ -603,7 +603,7 @@ rhythmdb_class_init (RhythmDBClass *klass)
 	 *
 	 * Emitted to request creation of a #GMountOperation to use to mount a volume.
 	 *
-	 * Return value: a #GMountOperation (usually actually a #GtkMountOperation)
+	 * Returns: (transfer full): a #GMountOperation (usually actually a #GtkMountOperation)
 	 */
 	rhythmdb_signals[CREATE_MOUNT_OP] =
 		g_signal_new ("create-mount-op",
@@ -1698,7 +1698,7 @@ rhythmdb_entry_allocate (RhythmDB *db,
  * Callers should use the RHYTHMDB_ENTRY_GET_TYPE_DATA macro for
  * a slightly more friendly interface to this functionality.
  *
- * Return value: type-specific data pointer
+ * Return value: (transfer none): type-specific data pointer
  */
 gpointer
 rhythmdb_entry_get_type_data (RhythmDBEntry *entry,
@@ -3895,7 +3895,7 @@ rhythmdb_entry_lookup_from_string (RhythmDB *db,
 /**
  * rhythmdb_entry_foreach:
  * @db: a #RhythmDB.
- * @func: the function to call with each entry.
+ * @func: (scope call): the function to call with each entry.
  * @data: user data to pass to the function.
  *
  * Calls the given function for each of the entries in the database.
@@ -3930,7 +3930,7 @@ rhythmdb_entry_count (RhythmDB *db)
  * rhythmdb_entry_foreach_by_type:
  * @db: a #RhythmDB.
  * @entry_type: the type of entry to retrieve
- * @func: the function to call with each entry
+ * @func: (scope call): the function to call with each entry
  * @data: user data to pass to the function.
  *
  * Calls the given function for each of the entries in the database
@@ -4428,19 +4428,19 @@ rhythmdb_is_busy (RhythmDB *db)
  * rhythmdb_get_progress_info:
  * @db: a #RhythmDB.
  * @text: used to return progress text
- * @fraction: used to return progress fraction
+ * @progress: used to return progress fraction
  *
  * Provides progress information for rhythmdb operations, if any are running.
  */
 void
-rhythmdb_get_progress_info (RhythmDB *db, char **text, float *fraction)
+rhythmdb_get_progress_info (RhythmDB *db, char **text, float *progress)
 {
 	if (db->priv->stat_thread_running && db->priv->stat_thread_count > 0) {
 		g_free (*text);
 		*text = g_strdup_printf (_("Checking (%d/%d)"),
 					 db->priv->stat_thread_done,
 					 db->priv->stat_thread_count);
-		*fraction = ((float)db->priv->stat_thread_done /
+		*progress = ((float)db->priv->stat_thread_done /
 			     (float)db->priv->stat_thread_count);
 	}
 }
@@ -4596,7 +4596,7 @@ rhythmdb_entry_type_foreach (RhythmDB *db,
  * Locates a #RhythmDBEntryType by name. Returns NULL if no entry
  * type is registered with the specified name.
  *
- * Returns: the #RhythmDBEntryType
+ * Returns: (transfer none): the #RhythmDBEntryType
  */
 RhythmDBEntryType *
 rhythmdb_entry_type_get_by_name (RhythmDB *db,
@@ -4999,7 +4999,7 @@ rhythmdb_entry_get_uint64 (RhythmDBEntry *entry,
  * entry type properties, to check that entries are of the same type,
  * and to call entry type methods.
  *
- * Return value: the #RhythmDBEntryType for @entry
+ * Return value: (transfer none): the #RhythmDBEntryType for @entry
  */
 RhythmDBEntryType *
 rhythmdb_entry_get_entry_type (RhythmDBEntry *entry)
@@ -5016,7 +5016,7 @@ rhythmdb_entry_get_entry_type (RhythmDBEntry *entry)
  *
  * Returns the value of an object property of @entry.
  *
- * Return value: property value
+ * Return value: (transfer none): property value
  */
 GObject *
 rhythmdb_entry_get_object (RhythmDBEntry *entry,
diff --git a/shell/rb-history.c b/shell/rb-history.c
index f5f5f99..cae1a31 100644
--- a/shell/rb-history.c
+++ b/shell/rb-history.c
@@ -136,7 +136,7 @@ rb_history_class_init (RBHistoryClass *klass)
 /**
  * rb_history_new:
  * @truncate_on_play: Whether rb_history_set_playing() should truncate the history
- * @destroyer: function to call when removing an entry from the history
+ * @destroyer: (scope async): function to call when removing an entry from the history
  * @destroy_userdata: data to pass to @destroyer
  *
  * Creates a new history instance.
@@ -238,7 +238,7 @@ rb_history_get_property (GObject *object,
 /**
  * rb_history_set_destroy_notify:
  * @hist: a #RBHistory
- * @destroyer: function to call when removing an entry from the history
+ * @destroyer: (scope async): function to call when removing an entry from the history
  * @destroy_userdata: data to pass to @destroyer
  *
  * Sets a new function to call when removing entries from the history.
diff --git a/shell/rb-playlist-manager.c b/shell/rb-playlist-manager.c
index 2b85079..d9505ee 100644
--- a/shell/rb-playlist-manager.c
+++ b/shell/rb-playlist-manager.c
@@ -725,7 +725,7 @@ append_new_playlist_source (RBPlaylistManager *mgr, RBPlaylistSource *source)
 }
 
 /**
- * rb_playlist_manager_load_playlists
+ * rb_playlist_manager_load_playlists:
  * @mgr: the #RBPlaylistManager
  *
  * Loads the user's playlists, or if the playlist file does not exists,
@@ -922,7 +922,7 @@ save_playlist_cb (GtkTreeModel *model,
 }
 
 /**
- * rb_playlist_manager_save_playlists
+ * rb_playlist_manager_save_playlists:
  * @mgr: the #RBPlaylistManager
  * @force: if TRUE, save playlists synchronously and unconditionally
  *
@@ -978,15 +978,15 @@ rb_playlist_manager_save_playlists (RBPlaylistManager *mgr, gboolean force)
 }
 
 /**
- * rb_playlist_manager_new_playlist
+ * rb_playlist_manager_new_playlist:
  * @mgr: the #RBPlaylistManager
  * @suggested_name: optional name to use for the new playlist
  * @automatic: if TRUE, create an auto playlist
  *
  * Creates a new playlist and adds it to the source list.
  *
- * Return value: the new playlist object.
- **/
+ * Return value: (transfer none): the new playlist object.
+ */
 RBSource *
 rb_playlist_manager_new_playlist (RBPlaylistManager *mgr,
 				  const char *suggested_name,
@@ -1115,7 +1115,7 @@ create_name_from_selection_data (RBPlaylistManager *mgr,
 }
 
 /**
- * rb_playlist_manager_new_playlist_from_selection_data
+ * rb_playlist_manager_new_playlist_from_selection_data:
  * @mgr: the #RBPlaylistManager
  * @data: the #GtkSelectionData from which to create a playlist
  *
@@ -1123,7 +1123,7 @@ create_name_from_selection_data (RBPlaylistManager *mgr,
  * Used to implement playlist creation through drag and drop
  * to the source list.
  *
- * Return value: the new playlist.
+ * Return value: (transfer none): the new playlist.
  **/
 RBSource *
 rb_playlist_manager_new_playlist_from_selection_data (RBPlaylistManager *mgr,
@@ -1661,7 +1661,7 @@ rb_playlist_manager_get_playlists (RBPlaylistManager *mgr)
 }
 
 /**
- * rb_playlist_manager_get_playlist_names
+ * rb_playlist_manager_get_playlist_names:
  * @mgr: the #RBPlaylistManager
  * @playlists: (out callee-allocates) (transfer full): holds the array of playlist names on reutrn
  * @error: holds a #GError on return on failure
@@ -1751,7 +1751,7 @@ _get_playlist_by_name (RBPlaylistManager *mgr,
 }
 
 /**
- * rb_playlist_manager_create_static_playlist
+ * rb_playlist_manager_create_static_playlist:
  * @mgr: the #RBPlaylistManager
  * @name: name of the new playlist
  * @error: holds a #GError on return on failure
@@ -1781,7 +1781,7 @@ rb_playlist_manager_create_static_playlist (RBPlaylistManager *mgr,
 }
 
 /**
- * rb_playlist_manager_delete_playlist
+ * rb_playlist_manager_delete_playlist:
  * @mgr: the #RBPlaylistManager
  * @name: name of the playlist to delete
  * @error: holds a #GError on return on failure
@@ -1811,7 +1811,7 @@ rb_playlist_manager_delete_playlist (RBPlaylistManager *mgr,
 }
 
 /**
- * rb_playlist_manager_add_to_playlist
+ * rb_playlist_manager_add_to_playlist:
  * @mgr: the #RBPlaylistManager
  * @name: name of the playlist to add to
  * @uri: URI of the entry to add to the playlist
@@ -1851,7 +1851,7 @@ rb_playlist_manager_add_to_playlist (RBPlaylistManager *mgr,
 }
 
 /**
- * rb_playlist_manager_remove_from_playlist
+ * rb_playlist_manager_remove_from_playlist:
  * @mgr: the #RBPlaylistManager
  * @name: name of the playlist to remove from
  * @uri: URI of the entry to remove from the playlist
@@ -1893,7 +1893,7 @@ rb_playlist_manager_remove_from_playlist (RBPlaylistManager *mgr,
 }
 
 /**
- * rb_playlist_manager_export_playlist
+ * rb_playlist_manager_export_playlist:
  * @mgr: the #RBPlaylistManager
  * @name: name of the playlist to export
  * @uri: playlist save location
diff --git a/shell/rb-plugin.c b/shell/rb-plugin.c
index dc84c06..2b84291 100644
--- a/shell/rb-plugin.c
+++ b/shell/rb-plugin.c
@@ -224,7 +224,7 @@ rb_plugin_is_configurable (RBPlugin *plugin)
  * the dialog instance the first time it is created and just return it
  * thereafter.
  *
- * Return value: configuration widget for @plugin
+ * Return value: (transfer none): configuration widget for @plugin
  */
 GtkWidget *
 rb_plugin_create_configure_dialog (RBPlugin *plugin)
diff --git a/shell/rb-shell-preferences.c b/shell/rb-shell-preferences.c
index 4419b58..153433a 100644
--- a/shell/rb-shell-preferences.c
+++ b/shell/rb-shell-preferences.c
@@ -717,7 +717,7 @@ get_box_for_location (RBShellPreferences *prefs, RBShellPrefsUILocation location
 
 /**
  * rb_shell_preferences_add_widget:
- * @shell: the #RBShellPreferences
+ * @prefs: the #RBShellPreferences
  * @widget: the #GtkWidget to insert into the preferences window
  * @location: the location at which to insert the widget
  * @expand: whether the widget should be given extra space
@@ -742,7 +742,7 @@ rb_shell_preferences_add_widget (RBShellPreferences *prefs,
 
 /**
  * rb_shell_preferences_remove_widget:
- * @shell: the #RBShellPreferences
+ * @prefs: the #RBShellPreferences
  * @widget: the #GtkWidget to remove from the preferences window
  * @location: the UI location to which the widget was originally added
  *
diff --git a/shell/rb-shell.c b/shell/rb-shell.c
index 06a26f9..78234c4 100644
--- a/shell/rb-shell.c
+++ b/shell/rb-shell.c
@@ -1969,7 +1969,7 @@ rb_shell_db_save_error_cb (RhythmDB *db,
  * Looks up and returns the source that owns entries of the specified
  * type.
  *
- * Return value: source instance, if any
+ * Return value: (transfer none): source instance, if any
  */
 RBSource *
 rb_shell_get_source_by_entry_type (RBShell *shell,
diff --git a/sources/rb-source.c b/sources/rb-source.c
index b19132f..f5daf28 100644
--- a/sources/rb-source.c
+++ b/sources/rb-source.c
@@ -884,7 +884,7 @@ rb_source_update_play_statistics (RBSource *source,
  *
  * Returns the entry view widget for the source.
  *
- * Return value: the #RBEntryView instance for the source
+ * Return value: (transfer none): the #RBEntryView instance for the source
  */
 RBEntryView *
 rb_source_get_entry_view (RBSource *source)
@@ -978,7 +978,7 @@ rb_source_search (RBSource *source,
  * configuration widget. The widget will be displayed in a 
  * page in the preferences dialog.
  *
- * Return value: configuration widget
+ * Return value: (transfer none): configuration widget
  */
 GtkWidget *
 rb_source_get_config_widget (RBSource *source,
@@ -1147,7 +1147,7 @@ rb_source_copy (RBSource *source)
  * is returned so the caller can monitor the transfer progress.  The caller does not
  * own a reference on the batch object.
  *
- * Return value: the #RBTrackTransferBatch used to perform the transfer (if any)
+ * Return value: (transfer none): the #RBTrackTransferBatch used to perform the transfer (if any)
  */
 RBTrackTransferBatch *
 rb_source_paste (RBSource *source, GList *entries)
diff --git a/sources/rb-sourcelist-model.c b/sources/rb-sourcelist-model.c
index fe563f1..bd83b89 100644
--- a/sources/rb-sourcelist-model.c
+++ b/sources/rb-sourcelist-model.c
@@ -250,7 +250,7 @@ rb_sourcelist_model_finalize (GObject *object)
  * This constructs both the GtkTreeStore holding the source
  * data and the filter model that hides invisible sources.
  * 
- * Return value: the #RBSourceListModel
+ * Return value: (transfer full): the #RBSourceListModel
  */
 GtkTreeModel *
 rb_sourcelist_model_new (void)
diff --git a/widgets/rb-dialog.c b/widgets/rb-dialog.c
index a076806..1648865 100644
--- a/widgets/rb-dialog.c
+++ b/widgets/rb-dialog.c
@@ -116,7 +116,7 @@ rb_error_dialog (GtkWindow *parent,
  * After creating the dialog, the caller should connect a handler to its 
  * 'response' signal to process the user's selected files or folders.
  *
- * Return value: the file chooser #GtkWidget
+ * Return value: (transfer full): the file chooser #GtkWidget
  */
 GtkWidget *
 rb_file_chooser_new (const char *title,
diff --git a/widgets/rb-segmented-bar.c b/widgets/rb-segmented-bar.c
index d089d74..c947f62 100644
--- a/widgets/rb-segmented-bar.c
+++ b/widgets/rb-segmented-bar.c
@@ -859,6 +859,14 @@ GtkWidget *rb_segmented_bar_new (void)
 	return g_object_new (RB_TYPE_SEGMENTED_BAR, NULL);
 }
 
+/**
+ * rb_segmented_bar_set_value_formatter:
+ * @bar: a #RBSegmentedBar
+ * @formatter: (scope async): the formatter function to use
+ * @data: data to pass to the formatter
+ *
+ * Sets a value formatter function to use for the bar.
+ */
 void rb_segmented_bar_set_value_formatter (RBSegmentedBar *bar,
 					   RBSegmentedBarValueFormatter formatter,
 					   gpointer data)



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/sources/rb-media-player-source.c b/sources/rb-media-player-source.c
index f6fd36c..644e346 100644
--- a/sources/rb-media-player-source.c
+++ b/sources/rb-media-player-source.c
@@ -273,15 +273,15 @@ rb_media_player_source_get_free_space (RBMediaPlayerSource *source)
  * rb_media_player_source_get_entries:
  * @source: the #RBMediaPlayerSource
  * @category: the sync category name
- * @map: (element-type utf8 RhythmDB.Entry): map to hold the entries
+ * @entries: (element-type utf8 RhythmDB.Entry): map to hold the entries
  */
 void
 rb_media_player_source_get_entries (RBMediaPlayerSource *source,
 				    const char *category,
-				    GHashTable *map)
+				    GHashTable *entries)
 {
 	RBMediaPlayerSourceClass *klass = RB_MEDIA_PLAYER_SOURCE_GET_CLASS (source);
-	klass->impl_get_entries (source, category, map);
+	klass->impl_get_entries (source, category, entries);
 }
 
 /**
@@ -289,19 +289,19 @@ rb_media_player_source_get_entries (RBMediaPlayerSource *source,
  * @source: the #RBMediaPlayerSource
  * @entries: (element-type RhythmDB.Entry) (transfer full): list of entries to delete
  * @callback: callback to call on completion
  * @callback_data: (closure) (scope notified): data for callback
  * @destroy_data: callback to free the callback data
  */
 void
 rb_media_player_source_delete_entries	(RBMediaPlayerSource *source,
 					 GList *entries,
 					 RBMediaPlayerSourceDeleteCallback callback,
-					 gpointer callback_data,
+					 gpointer user_data,
 					 GDestroyNotify destroy_data)
 {
 	RBMediaPlayerSourceClass *klass = RB_MEDIA_PLAYER_SOURCE_GET_CLASS (source);
 
-	klass->impl_delete_entries (source, entries, callback, callback_data, destroy_data);
+	klass->impl_delete_entries (source, entries, callback, user_data, destroy_data);
 }
 
 static void
@@ -289,19 +289,19 @@ rb_media_player_source_get_entries (RBMediaPlayerSource *source,
  * @entries: (element-type RhythmDB.Entry) (transfer full): list of entries to delete
  * @callback: callback to call on completion
- * @callback_data: (closure) (scope notified): data for callback
+ * @user_data: (closure) (scope notified): data for callback
  * @destroy_data: callback to free the callback data
  */